Struct google_vision1::api::AsyncBatchAnnotateFilesRequest[][src]

pub struct AsyncBatchAnnotateFilesRequest {
    pub parent: Option<String>,
    pub requests: Option<Vec<AsyncAnnotateFileRequest>>,
}

Multiple async file annotation requests are batched into a single service call.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

parent: Option<String>

Optional. Target project and location to make a call. Format: projects/{project-id}/locations/{location-id}. If no parent is specified, a region will be chosen automatically. Supported location-ids: us: USA country only, asia: East asia areas, like Japan, Taiwan, eu: The European Union. Example: projects/project-A/locations/eu.

requests: Option<Vec<AsyncAnnotateFileRequest>>

Required. Individual async file annotation requests for this batch.