pub struct AsyncBatchAnnotateImagesRequest {
pub labels: Option<HashMap<String, String>>,
pub output_config: Option<OutputConfig>,
pub parent: Option<String>,
pub requests: Option<Vec<AnnotateImageRequest>>,
}Expand description
Request for async image annotation for a list of images.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- async batch annotate images (request)
- images async batch annotate projects (request)
- locations images async batch annotate projects (request)
Fields
labels: Option<HashMap<String, String>>Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter.
output_config: Option<OutputConfig>Required. The desired output location and metadata (e.g. format).
parent: Option<String>Optional. Target project and location to make a call. Format: projects/{project-id}/locations/{location-id}. If no parent is specified, a region will be chosen automatically. Supported location-ids: us: USA country only, asia: East asia areas, like Japan, Taiwan, eu: The European Union. Example: projects/project-A/locations/eu.
requests: Option<Vec<AnnotateImageRequest>>Required. Individual image annotation requests for this batch.