Struct google_vision1::api::BatchAnnotateFilesResponse[][src]

pub struct BatchAnnotateFilesResponse {
    pub responses: Option<Vec<AnnotateFileResponse>>,
}

A list of file annotation responses.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

responses: Option<Vec<AnnotateFileResponse>>

The list of file annotation responses, each response corresponding to each AnnotateFileRequest in BatchAnnotateFilesRequest.