pub struct CropHint {
pub bounding_poly: Option<BoundingPoly>,
pub confidence: Option<f32>,
pub importance_fraction: Option<f32>,
}Expand description
Single crop hint that is used to generate a new crop when serving an image.
This type is not used in any activity, and only used as part of another schema.
Fields
bounding_poly: Option<BoundingPoly>The bounding polygon for the crop region. The coordinates of the bounding box are in the original image’s scale.
confidence: Option<f32>Confidence of this being a salient region. Range [0, 1].
importance_fraction: Option<f32>Fraction of importance of this salient region with respect to the original image.