Struct google_vision1::api::CropHintsAnnotation [−][src]
Set of crop hints that are used to generate new crops when serving images.
This type is not used in any activity, and only used as part of another schema.
Fields
crop_hints: Option<Vec<CropHint>>Crop hint results.