Struct google_vision1::api::DominantColorsAnnotation [−][src]
Set of dominant colors and their corresponding scores.
This type is not used in any activity, and only used as part of another schema.
Fields
colors: Option<Vec<ColorInfo>>RGB color values with their score and pixel fraction.