Struct google_vision1::api::EntityAnnotation [−][src]
Set of detected entity features.
This type is not used in any activity, and only used as part of another schema.
Fields
bounding_poly: Option<BoundingPoly>Image region to which this entity belongs. Not produced for LABEL_DETECTION features.
confidence: Option<f32>Deprecated. Use score instead. The accuracy of the entity detection in an image. For example, for an image in which the “Eiffel Tower” entity is detected, this field represents the confidence that there is a tower in the query image. Range [0, 1].
description: Option<String>Entity textual description, expressed in its locale language.
locale: Option<String>The language code for the locale in which the entity textual description is expressed.
locations: Option<Vec<LocationInfo>>The location information for the detected entity. Multiple LocationInfo elements can be present because one location may indicate the location of the scene in the image, and another location may indicate the location of the place where the image was taken. Location information is usually present for landmarks.
mid: Option<String>Opaque entity ID. Some IDs may be available in Google Knowledge Graph Search API.
properties: Option<Vec<Property>>Some entities may have optional user-supplied Property (name/value) fields, such a score or string that qualifies the entity.
score: Option<f32>Overall score of the result. Range [0, 1].
topicality: Option<f32>The relevancy of the ICA (Image Content Annotation) label to the image. For example, the relevancy of “tower” is likely higher to an image containing the detected “Eiffel Tower” than to an image containing a detected distant towering building, even though the confidence that there is a tower in each image may be the same. Range [0, 1].