Struct google_vision1::api::Feature[][src]

pub struct Feature {
    pub max_results: Option<i32>,
    pub model: Option<String>,
    pub type_: Option<String>,
}

The type of Google Cloud Vision API detection to perform, and the maximum number of results to return for that type. Multiple Feature objects can be specified in the features list.

This type is not used in any activity, and only used as part of another schema.

Fields

max_results: Option<i32>

Maximum number of results of this type. Does not apply to TEXT_DETECTION, DOCUMENT_TEXT_DETECTION, or CROP_HINTS.

model: Option<String>

Model to use for the feature. Supported values: “builtin/stable” (the default if unset) and “builtin/latest”.

type_: Option<String>

The feature type.