Struct google_vision1::api::GcsSource [−][src]
The Google Cloud Storage location where the input will be read from.
This type is not used in any activity, and only used as part of another schema.
Fields
uri: Option<String>Google Cloud Storage URI for the input file. This must only be a Google Cloud Storage object. Wildcards are not currently supported.