Struct google_vision1::api::ImageContext [−][src]
Image context and/or feature-specific parameters.
This type is not used in any activity, and only used as part of another schema.
Fields
crop_hints_params: Option<CropHintsParams>Parameters for crop hints annotation request.
language_hints: Option<Vec<String>>List of languages to use for TEXT_DETECTION. In most cases, an empty value yields the best results since it enables automatic language detection. For languages based on the Latin alphabet, setting language_hints is not needed. In rare cases, when the language of the text in the image is known, setting a hint will help get better results (although it will be a significant hindrance if the hint is wrong). Text detection returns an error if one or more of the specified languages is not one of the supported languages.
lat_long_rect: Option<LatLongRect>Not used.
product_search_params: Option<ProductSearchParams>Parameters for product search.
text_detection_params: Option<TextDetectionParams>Parameters for text detection and document text detection.
web_detection_params: Option<WebDetectionParams>Parameters for web detection.