Struct google_vision1::api::InputConfig [−][src]
The desired input location and metadata.
This type is not used in any activity, and only used as part of another schema.
Fields
content: Option<String>File content, represented as a stream of bytes. Note: As with all bytes fields, protobuffers use a pure binary representation, whereas JSON representations use base64. Currently, this field only works for BatchAnnotateFiles requests. It does not work for AsyncBatchAnnotateFiles requests.
gcs_source: Option<GcsSource>The Google Cloud Storage location to read the input from.
mime_type: Option<String>The type of the file. Currently only “application/pdf”, “image/tiff” and “image/gif” are supported. Wildcards are not supported.