pub struct ObjectAnnotation {
pub language_code: Option<String>,
pub mid: Option<String>,
pub name: Option<String>,
pub score: Option<f32>,
}Expand description
Prediction for what the object in the bounding box is.
This type is not used in any activity, and only used as part of another schema.
Fields
language_code: Option<String>The BCP-47 language code, such as “en-US” or “sr-Latn”. For more information, see http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
mid: Option<String>Object ID that should align with EntityAnnotation mid.
name: Option<String>Object name, expressed in its language_code language.
score: Option<f32>Score of the result. Range [0, 1].