Struct google_vision1::api::Paragraph[][src]

pub struct Paragraph {
    pub bounding_box: Option<BoundingPoly>,
    pub confidence: Option<f32>,
    pub property: Option<TextProperty>,
    pub words: Option<Vec<Word>>,
}

Structural unit of text representing a number of words in certain order.

This type is not used in any activity, and only used as part of another schema.

Fields

bounding_box: Option<BoundingPoly>

The bounding box for the paragraph. The vertices are in the order of top-left, top-right, bottom-right, bottom-left. When a rotation of the bounding box is detected the rotation is represented as around the top-left corner as defined when the text is read in the ‘natural’ orientation. For example: * when the text is horizontal it might look like: 0––1 | | 3––2 * when it’s rotated 180 degrees around the top-left corner it becomes: 2––3 | | 1––0 and the vertex order will still be (0, 1, 2, 3).

confidence: Option<f32>

Confidence of the OCR results for the paragraph. Range [0, 1].

property: Option<TextProperty>

Additional information detected for the paragraph.

words: Option<Vec<Word>>

List of all words in this paragraph.