Struct google_vision1::api::TextDetectionParams [−][src]
Parameters for text detections. This is used to control TEXT_DETECTION and DOCUMENT_TEXT_DETECTION features.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_text_detection_confidence_score: Option<bool>By default, Cloud Vision API only includes confidence score for DOCUMENT_TEXT_DETECTION result. Set the flag to true to include confidence score for TEXT_DETECTION as well.