pub struct WebEntity {
pub description: Option<String>,
pub entity_id: Option<String>,
pub score: Option<f32>,
}Expand description
Entity deduced from similar images on the Internet.
This type is not used in any activity, and only used as part of another schema.
Fields
description: Option<String>Canonical description of the entity, in English.
entity_id: Option<String>Opaque entity ID.
score: Option<f32>Overall relevancy score for the entity. Not normalized and not comparable across different image queries.