pub struct AnnotateFileRequest {
pub features: Option<Vec<Feature>>,
pub image_context: Option<ImageContext>,
pub input_config: Option<InputConfig>,
pub pages: Option<Vec<i32>>,
}Expand description
A request to annotate one single file, e.g. a PDF, TIFF or GIF file.
This type is not used in any activity, and only used as part of another schema.
Fields
features: Option<Vec<Feature>>Required. Requested features.
image_context: Option<ImageContext>Additional context that may accompany the image(s) in the file.
input_config: Option<InputConfig>Required. Information about the input file.
pages: Option<Vec<i32>>Pages of the file to perform image annotation. Pages starts from 1, we assume the first page of the file is page 1. At most 5 pages are supported per request. Pages can be negative. Page 1 means the first page. Page 2 means the second page. Page -1 means the last page. Page -2 means the second to the last page. If the file is GIF instead of PDF or TIFF, page refers to GIF frames. If this field is empty, by default the service performs image annotation for the first 5 pages of the file.