AnnotateFileResponse

Struct AnnotateFileResponse 

pub struct AnnotateFileResponse {
    pub error: Option<Status>,
    pub input_config: Option<InputConfig>,
    pub responses: Option<Vec<AnnotateImageResponse>>,
    pub total_pages: Option<i32>,
}
Response to a single file annotation request. A file may contain one or more images, which individually have their own responses.

This type is not used in any activity, and only used as part of another schema.

Fields

error: Option<Status>

If set, represents the error message for the failed request. The responses field will not be set in this case.

input_config: Option<InputConfig>

Information about the file for which this response is generated.

responses: Option<Vec<AnnotateImageResponse>>

Individual responses to images found within the file. This field will be empty if the error field is set.

total_pages: Option<i32>

This field gives the total number of pages in the file.