pub struct AnnotateImageResponse {Show 14 fields
pub context: Option<ImageAnnotationContext>,
pub crop_hints_annotation: Option<CropHintsAnnotation>,
pub error: Option<Status>,
pub face_annotations: Option<Vec<FaceAnnotation>>,
pub full_text_annotation: Option<TextAnnotation>,
pub image_properties_annotation: Option<ImageProperties>,
pub label_annotations: Option<Vec<EntityAnnotation>>,
pub landmark_annotations: Option<Vec<EntityAnnotation>>,
pub localized_object_annotations: Option<Vec<LocalizedObjectAnnotation>>,
pub logo_annotations: Option<Vec<EntityAnnotation>>,
pub product_search_results: Option<ProductSearchResults>,
pub safe_search_annotation: Option<SafeSearchAnnotation>,
pub text_annotations: Option<Vec<EntityAnnotation>>,
pub web_detection: Option<WebDetection>,
}Expand description
Response to an image annotation request.
This type is not used in any activity, and only used as part of another schema.
Fields
context: Option<ImageAnnotationContext>If present, contextual information is needed to understand where this image comes from.
crop_hints_annotation: Option<CropHintsAnnotation>If present, crop hints have completed successfully.
error: Option<Status>If set, represents the error message for the operation. Note that filled-in image annotations are guaranteed to be correct, even when error is set.
face_annotations: Option<Vec<FaceAnnotation>>If present, face detection has completed successfully.
full_text_annotation: Option<TextAnnotation>If present, text (OCR) detection or document (OCR) text detection has completed successfully. This annotation provides the structural hierarchy for the OCR detected text.
image_properties_annotation: Option<ImageProperties>If present, image properties were extracted successfully.
label_annotations: Option<Vec<EntityAnnotation>>If present, label detection has completed successfully.
landmark_annotations: Option<Vec<EntityAnnotation>>If present, landmark detection has completed successfully.
localized_object_annotations: Option<Vec<LocalizedObjectAnnotation>>If present, localized object detection has completed successfully. This will be sorted descending by confidence score.
logo_annotations: Option<Vec<EntityAnnotation>>If present, logo detection has completed successfully.
product_search_results: Option<ProductSearchResults>If present, product search has completed successfully.
safe_search_annotation: Option<SafeSearchAnnotation>If present, safe-search annotation has completed successfully.
text_annotations: Option<Vec<EntityAnnotation>>If present, text (OCR) detection has completed successfully.
web_detection: Option<WebDetection>If present, web detection has completed successfully.