Struct google_vision1::api::BatchAnnotateFilesRequest [−][src]
A list of requests to annotate files using the BatchAnnotateFiles API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- annotate files (request)
- files annotate projects (request)
- locations files annotate projects (request)
Fields
parent: Option<String>Optional. Target project and location to make a call. Format: projects/{project-id}/locations/{location-id}. If no parent is specified, a region will be chosen automatically. Supported location-ids: us: USA country only, asia: East asia areas, like Japan, Taiwan, eu: The European Union. Example: projects/project-A/locations/eu.
requests: Option<Vec<AnnotateFileRequest>>Required. The list of file annotation requests. Right now we support only one AnnotateFileRequest in BatchAnnotateFilesRequest.