pub struct Block {
pub block_type: Option<String>,
pub bounding_box: Option<BoundingPoly>,
pub confidence: Option<f32>,
pub paragraphs: Option<Vec<Paragraph>>,
pub property: Option<TextProperty>,
}Expand description
Logical element on the page.
This type is not used in any activity, and only used as part of another schema.
Fields
block_type: Option<String>Detected block type (text, image etc) for this block.
bounding_box: Option<BoundingPoly>The bounding box for the block. The vertices are in the order of top-left, top-right, bottom-right, bottom-left. When a rotation of the bounding box is detected the rotation is represented as around the top-left corner as defined when the text is read in the ‘natural’ orientation. For example: * when the text is horizontal it might look like: 0––1 | | 3––2 * when it’s rotated 180 degrees around the top-left corner it becomes: 2––3 | | 1––0 and the vertex order will still be (0, 1, 2, 3).
confidence: Option<f32>Confidence of the OCR results on the block. Range [0, 1].
paragraphs: Option<Vec<Paragraph>>List of paragraphs in this block (if this blocks is of type text).
property: Option<TextProperty>Additional information detected for the block.