pub struct ColorInfo {
pub color: Option<Color>,
pub pixel_fraction: Option<f32>,
pub score: Option<f32>,
}Expand description
Color information consists of RGB channels, score, and the fraction of the image that the color occupies in the image.
This type is not used in any activity, and only used as part of another schema.
Fields
color: Option<Color>RGB components of the color.
pixel_fraction: Option<f32>The fraction of pixels the color occupies in the image. Value in range [0, 1].
score: Option<f32>Image-specific score for this color. Value in range [0, 1].