pub struct DominantColorsAnnotation {
pub colors: Option<Vec<ColorInfo>>,
}Expand description
Set of dominant colors and their corresponding scores.
This type is not used in any activity, and only used as part of another schema.
Fields
colors: Option<Vec<ColorInfo>>RGB color values with their score and pixel fraction.