FaceAnnotation

Struct FaceAnnotation 

pub struct FaceAnnotation {
Show 15 fields pub anger_likelihood: Option<String>, pub blurred_likelihood: Option<String>, pub bounding_poly: Option<BoundingPoly>, pub detection_confidence: Option<f32>, pub fd_bounding_poly: Option<BoundingPoly>, pub headwear_likelihood: Option<String>, pub joy_likelihood: Option<String>, pub landmarking_confidence: Option<f32>, pub landmarks: Option<Vec<Landmark>>, pub pan_angle: Option<f32>, pub roll_angle: Option<f32>, pub sorrow_likelihood: Option<String>, pub surprise_likelihood: Option<String>, pub tilt_angle: Option<f32>, pub under_exposed_likelihood: Option<String>,
}
A face annotation object contains the results of face detection.

This type is not used in any activity, and only used as part of another schema.

Fields

anger_likelihood: Option<String>

Anger likelihood.

blurred_likelihood: Option<String>

Blurred likelihood.

bounding_poly: Option<BoundingPoly>

The bounding polygon around the face. The coordinates of the bounding box are in the original image’s scale. The bounding box is computed to “frame” the face in accordance with human expectations. It is based on the landmarker results. Note that one or more x and/or y coordinates may not be generated in the BoundingPoly (the polygon will be unbounded) if only a partial face appears in the image to be annotated.

detection_confidence: Option<f32>

Detection confidence. Range [0, 1].

fd_bounding_poly: Option<BoundingPoly>

The fd_bounding_poly bounding polygon is tighter than the boundingPoly, and encloses only the skin part of the face. Typically, it is used to eliminate the face from any image analysis that detects the “amount of skin” visible in an image. It is not based on the landmarker results, only on the initial face detection, hence the fd (face detection) prefix.

headwear_likelihood: Option<String>

Headwear likelihood.

joy_likelihood: Option<String>

Joy likelihood.

landmarking_confidence: Option<f32>

Face landmarking confidence. Range [0, 1].

landmarks: Option<Vec<Landmark>>

Detected face landmarks.

pan_angle: Option<f32>

Yaw angle, which indicates the leftward/rightward angle that the face is pointing relative to the vertical plane perpendicular to the image. Range [-180,180].

roll_angle: Option<f32>

Roll angle, which indicates the amount of clockwise/anti-clockwise rotation of the face relative to the image vertical about the axis perpendicular to the face. Range [-180,180].

sorrow_likelihood: Option<String>

Sorrow likelihood.

surprise_likelihood: Option<String>

Surprise likelihood.

tilt_angle: Option<f32>

Pitch angle, which indicates the upwards/downwards angle that the face is pointing relative to the image’s horizontal plane. Range [-180,180].

under_exposed_likelihood: Option<String>

Under-exposed likelihood.