pub struct Page {
pub blocks: Option<Vec<Block>>,
pub confidence: Option<f32>,
pub height: Option<i32>,
pub property: Option<TextProperty>,
pub width: Option<i32>,
}Expand description
Detected page from OCR.
This type is not used in any activity, and only used as part of another schema.
Fields
blocks: Option<Vec<Block>>List of blocks of text, images etc on this page.
confidence: Option<f32>Confidence of the OCR results on the page. Range [0, 1].
height: Option<i32>Page height. For PDFs the unit is points. For images (including TIFFs) the unit is pixels.
property: Option<TextProperty>Additional information detected on the page.
width: Option<i32>Page width. For PDFs the unit is points. For images (including TIFFs) the unit is pixels.