Struct google_vision1::api::SafeSearchAnnotation [−][src]
Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).
This type is not used in any activity, and only used as part of another schema.
Fields
adult: Option<String>Represents the adult content likelihood for the image. Adult content may contain elements such as nudity, pornographic images or cartoons, or sexual activities.
medical: Option<String>Likelihood that this is a medical image.
racy: Option<String>Likelihood that the request image contains racy content. Racy content may include (but is not limited to) skimpy or sheer clothing, strategically covered nudity, lewd or provocative poses, or close-ups of sensitive body areas.
spoof: Option<String>Spoof likelihood. The likelihood that an modification was made to the image’s canonical version to make it appear funny or offensive.
violence: Option<String>Likelihood that this image contains violent content.