Struct google_vision1::api::TextAnnotation [−][src]
TextAnnotation contains a structured representation of OCR extracted text. The hierarchy of an OCR extracted text structure is like this: TextAnnotation -> Page -> Block -> Paragraph -> Word -> Symbol Each structural component, starting from Page, may further have their own properties. Properties describe detected languages, breaks etc.. Please refer to the TextAnnotation.TextProperty message definition below for more detail.
This type is not used in any activity, and only used as part of another schema.
Fields
pages: Option<Vec<Page>>List of pages detected by OCR.
text: Option<String>UTF-8 text detected on the pages.