pub struct TextDetectionParams {
pub advanced_ocr_options: Option<Vec<String>>,
pub enable_text_detection_confidence_score: Option<bool>,
}Expand description
Parameters for text detections. This is used to control TEXT_DETECTION and DOCUMENT_TEXT_DETECTION features.
This type is not used in any activity, and only used as part of another schema.
Fields
advanced_ocr_options: Option<Vec<String>>A list of advanced OCR options to further fine-tune OCR behavior. Current valid values are: - legacy_layout: a heuristics layout detection algorithm, which serves as an alternative to the current ML-based layout detection algorithm. Customers can choose the best suitable layout algorithm based on their situation.
enable_text_detection_confidence_score: Option<bool>By default, Cloud Vision API only includes confidence score for DOCUMENT_TEXT_DETECTION result. Set the flag to true to include confidence score for TEXT_DETECTION as well.