Struct google_vision1::api::WebDetection [−][src]
Relevant information for the image from the Internet.
This type is not used in any activity, and only used as part of another schema.
Fields
best_guess_labels: Option<Vec<WebLabel>>The service’s best guess as to the topic of the request image. Inferred from similar images on the open web.
full_matching_images: Option<Vec<WebImage>>Fully matching images from the Internet. Can include resized copies of the query image.
pages_with_matching_images: Option<Vec<WebPage>>Web pages containing the matching images from the Internet.
partial_matching_images: Option<Vec<WebImage>>Partial matching images from the Internet. Those images are similar enough to share some key-point features. For example an original image will likely have partial matching for its crops.
visually_similar_images: Option<Vec<WebImage>>The visually similar image results.
web_entities: Option<Vec<WebEntity>>Deduced entities from similar images on the Internet.